%define nginx_user nginx
%define nginx_group %{nginx_user}
%define nginx_home /var/lib/nginx
%define nginx_home_tmp %{nginx_home}/tmp
%define nginx_logdir /var/log/nginx
%define nginx_confdir %{_sysconfdir}/nginx
%define nginx_datadir %{_datadir}/nginx
%define nginx_webroot %{nginx_datadir}/html

Summary:	Robust, small and high performance http and reverse proxy server
Name:		nginx
Version:	1.0.15
%define subrel	1
Release:	%mkrel 2
Group:		System/Servers
# BSD License (two clause)
# http://www.freebsd.org/copyright/freebsd-license.html
License:	BSD
URL:		http://nginx.net/
Source0:	http://nginx.org/download/nginx-%{version}.tar.gz
Source1:	http://nginx.org/download/nginx-%{version}.tar.gz.asc
Source2:	%{name}.init
Source3:	%{name}.logrotate
Source4:	%{name}.sysconfig
Source5:	%{name}.service

Source6:    nginx.conf
Source7:    default.conf
Source8:    ssl.conf
Source9:    virtual.conf
Source100:	index.html
Source101:	poweredby.png
Source102:	nginx-logo.png
Source103:	50x.html
Source104:	404.html

Patch0:		nginx-1.4.3-CVE-2013-4547.patch

Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
BuildRequires:  GeoIP-devel
BuildRequires:  gd-devel
BuildRequires:  libxslt-devel
BuildRequires:	openssl-devel
BuildRequires:	pcre-devel
BuildRequires:	zlib-devel
BuildRequires:	perl-devel
BuildRequires:	perl(ExtUtils::Embed)
Requires:	pcre
Requires:	openssl
Provides:	webserver

%description
Nginx [engine x] is an HTTP(S) server, HTTP(S) reverse proxy and IMAP/POP3
proxy server written by Igor Sysoev.

%prep
%setup -q
%patch0 -p0 -b .CVE-2013-4547

%build
%serverbuild
# nginx does not utilize a standard configure script.  It has its own
# and the standard configure options cause the nginx configure script
# to error out.  This is is also the reason for the DESTDIR environment
# variable.  The configure script(s) have been patched (Patch1 and
# Patch2) in order to support installing into a build environment.
export DESTDIR=%{buildroot}
./configure \
    --prefix=%{nginx_datadir} \
    --sbin-path=%{_sbindir}/%{name} \
    --conf-path=%{nginx_confdir}/%{name}.conf \
    --error-log-path=%{nginx_logdir}/error.log \
    --http-log-path=%{nginx_logdir}/access.log \
    --http-client-body-temp-path=%{nginx_home_tmp}/client_body \
    --http-proxy-temp-path=%{nginx_home_tmp}/proxy \
    --http-fastcgi-temp-path=%{nginx_home_tmp}/fastcgi \
    --http-uwsgi-temp-path=%{nginx_home_tmp}/uwsgi \
    --http-scgi-temp-path=%{nginx_home_tmp}/scgi \
    --pid-path=/run/%{name}.pid \
    --lock-path=/run/lock/subsys/%{name} \
    --user=%{nginx_user} \
    --group=%{nginx_group} \
    --with-file-aio \
    --with-ipv6 \
    --with-http_ssl_module \
    --with-http_realip_module \
    --with-http_addition_module \
    --with-http_xslt_module \
    --with-http_image_filter_module \
    --with-http_geoip_module \
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_flv_module \
    --with-http_mp4_module \
    --with-http_gzip_static_module \
    --with-http_random_index_module \
    --with-http_secure_link_module \
    --with-http_degradation_module \
    --with-http_stub_status_module \
    --with-http_perl_module \
    --with-mail \
    --with-mail_ssl_module \
    --with-cc-opt="$CFLAGS $(pcre-config --cflags)" 

%make

%install
rm -rf %{buildroot}

%makeinstall_std INSTALLDIRS=vendor

%{__install} -d -m 755 %{buildroot}%{_initrddir}
%{__install} -m 755 %{SOURCE2} %{buildroot}%{_initrddir}/%{name}

%{__install} -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
%{__install} -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

%{__install} -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

%{__install} -d -m 755 %{buildroot}%{_unitdir}
%{__install} -m 644 %{SOURCE5} %{buildroot}%{_unitdir}

%{__install} -d -m 0755 %{buildroot}%{nginx_confdir}/conf.d
%{__install} -m 644 %{SOURCE6} %{SOURCE7} %{SOURCE8} %{SOURCE9} \
    %{buildroot}%{nginx_confdir}/conf.d

%{__install} -d -m 0755 %{buildroot}%{nginx_home_tmp}
%{__install} -d -m 0755 %{buildroot}%{nginx_logdir}
%{__install} -d -m 0755 %{buildroot}%{nginx_webroot}

%{__install} -p -m 0644 %{SOURCE100} %{SOURCE101} %{SOURCE102} \
	     	   	%{SOURCE103} %{SOURCE104} \
			%{buildroot}%{nginx_webroot}

# add current version
perl -pi -e "s|_VERSION_|%{version}|g" %{buildroot}%{nginx_webroot}/index.html

# convert to UTF-8 all files that give warnings.
for textfile in CHANGES; do
    mv $textfile $textfile.old
    iconv --from-code ISO8859-1 --to-code UTF-8 --output $textfile $textfile.old
    rm -f $textfile.old
done

install -d %{buildroot}%{_mandir}/man8
install -m0644 man/*.8 %{buildroot}%{_mandir}/man8/

%pre
%_pre_useradd %{nginx_user} %{nginx_home} /bin/false

%post
%_post_service %{nginx_user}

%preun
%_preun_service %{nginx_user}

%postun
%_postun_userdel %{nginx_user}

%files
%doc LICENSE CHANGES README
%{nginx_datadir}
%{_sbindir}/%{name}
%{_mandir}/man3/%{name}.3pm*
%{_mandir}/man8/*
%{_initrddir}/%{name}
%{_unitdir}/%{name}.service
%dir %{nginx_confdir}
%dir %{nginx_confdir}/conf.d
%config(noreplace) %{nginx_confdir}/conf.d/*.conf
%config(noreplace) %{nginx_confdir}/win-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf.default
%config(noreplace) %{nginx_confdir}/scgi_params
%config(noreplace) %{nginx_confdir}/scgi_params.default
%config(noreplace) %{nginx_confdir}/fastcgi.conf
%config(noreplace) %{nginx_confdir}/fastcgi.conf.default
%config(noreplace) %{nginx_confdir}/mime.types.default
%config(noreplace) %{nginx_confdir}/fastcgi_params
%config(noreplace) %{nginx_confdir}/fastcgi_params.default
%config(noreplace) %{nginx_confdir}/koi-win
%config(noreplace) %{nginx_confdir}/koi-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf
%config(noreplace) %{nginx_confdir}/mime.types
%config(noreplace) %{nginx_confdir}/uwsgi_params
%config(noreplace) %{nginx_confdir}/uwsgi_params.default
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{perl_vendorarch}/auto/%{name}
%{perl_vendorarch}/%{name}.pm
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home_tmp}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_logdir}


%changelog
* Wed Nov 20 2013 luigiwalser <luigiwalser> 1.0.15-2.1.mga2
+ Revision: 552070
- add upstream patch to fix CVE-2013-4547

  + tmb <tmb>
    - Require rpm-helper >= 0.24.8-1 for systemd support

* Thu Apr 19 2012 fwang <fwang> 1.0.15-1.mga2
+ Revision: 231795
- new version 1.0.15

* Mon Mar 19 2012 guillomovitch <guillomovitch> 1.0.14-2.mga2
+ Revision: 224503
- drop last mandriva references (#3815)

* Mon Mar 19 2012 guillomovitch <guillomovitch> 1.0.14-1.mga2
+ Revision: 224303
+ rebuild (emptylog)

* Thu Mar 15 2012 guillomovitch <guillomovitch> 1.0.10-2.mga2
+ Revision: 223512
- sync configuration files with fedora package
- drop useless apache dependency
- spec cleanup
- systemd support

* Mon Jan 09 2012 fwang <fwang> 1.0.10-1.mga2
+ Revision: 193691
- new version 1.0.10

* Fri Nov 04 2011 fwang <fwang> 1.0.9-1.mga2
+ Revision: 162665
- new version 1.0.9

* Thu Oct 20 2011 tv <tv> 1.0.8-2.mga2
+ Revision: 156981
- rebuild for new perl

* Sun Oct 02 2011 fwang <fwang> 1.0.8-1.mga2
+ Revision: 150974
- new version 1.0.8

* Sun Sep 18 2011 dmorgan <dmorgan> 1.0.6-2.mga2
+ Revision: 144695
- Change apache-conf require

* Wed Aug 31 2011 fwang <fwang> 1.0.6-1.mga2
+ Revision: 136890
- new version 1.0.6

* Wed Jul 20 2011 fwang <fwang> 1.0.5-1.mga2
+ Revision: 127063
- rediff conf patch
- add signature
- new version 1.0.5

* Thu Jun 16 2011 tv <tv> 1.0.4-1.mga2
+ Revision: 108442
- new relase
- vendor is mga not mdv
- s/mdv/mga/

* Sat Jun 11 2011 jquelin <jquelin> 1.0.0-2.mga2
+ Revision: 103442
- perl 5.14

* Wed Apr 13 2011 tv <tv> 1.0.0-1.mga1
+ Revision: 84509
- new release

* Sun Feb 20 2011 dmorgan <dmorgan> 0.9.3-1.mga1
+ Revision: 54507
- imported package nginx

